@@ -5,9 +5,11 @@ features of the library.
 """
 import inspect
 import imp
+import os
 import re
 import subprocess
 import urllib2
+from StringIO import StringIO
 from base64 import b64encode
 
 from getpass import getpass
@@ -34,14 +36,14 @@ def get_recipe_class(recipe, environment):
         raise e
 
 
-def call(command, stdin=None, env=None, cwd=None, bash=False):
+def call(command, stdin=None, env=os.environ, cwd=None, bash=False):
     if not bash:
         args = __whitespace_smart_split(command)
         p = subprocess.Popen(args, stdout=PIPE, stdin=PIPE, stderr=STDOUT, env=env, cwd=cwd)
         return p.communicate(input=stdin)[0]
     else:
         command = " ".join([__process(arg) for arg in __whitespace_smart_split(command)])
-        subprocess.call(command, shell=True, executable='/bin/bash')
+        subprocess.call(command, shell=True, executable='/bin/bash', cwd=cwd, env=env)
 
 
 def __process(arg):
@@ -52,7 +54,20 @@ def __process(arg):
     if arg[0] in ["'", '"', '-']:
         return arg
     else:
-        return re.escape(arg)
+        return __escape(arg)
+
+
+def __escape(s):
+    """
+    Custom escape module for bash
+    """
+    buf = StringIO()
+    for c in s:
+        if c in ['(', ')', ':']:
+            buf.write("\\" + c)
+        else:
+            buf.write(c)
+    return buf.getvalue()
 
 
 def __whitespace_smart_split(command):
@@ -108,16 +123,22 @@ def authenticated_get(username, password, url):
     return result.read()
 
 
-def prompt(prompt_string, default=None, secret=False):
+def prompt(prompt_string, default=None, secret=False, boolean=False):
     """
     Prompt user for a string, with a default value
+
+    * secret converts to password prompt
+    * boolean converts return value to boolean, checking for starting with a Y
     """
     prompt_string += (" (default %s): " % default if default else ": ")
     if secret:
         val = getpass(prompt_string)
     else:
         val = raw_input(prompt_string)
-    return (val if val else default)
+    val = (val if val else default)
+    if boolean:
+        val = val.lower().startswith('y')
+    return val
 
 
 def __recursive_import(module_name):
@@ -141,6 +162,27 @@ def __recursive_import(module_name):
         module = imp.load_module(name, module_file, pathname, description)
     return module
 
+
+# From:
+# http://stackoverflow.com/questions/377017/test-if-executable-exists-in-python
+def is_exe(fpath):
+    return os.path.isfile(fpath) and os.access(fpath, os.X_OK)
+
+
+def which(program):
+    fpath, fname = os.path.split(program)
+    if fpath:
+        if is_exe(program):
+            return program
+    else:
+        for path in os.environ["PATH"].split(os.pathsep):
+            path = path.strip('"')
+            exe_file = os.path.join(path, program)
+            if is_exe(exe_file):
+                return exe_file
+
+    return None
+
 if __name__ == '__main__':
     import doctest
     doctest.testmod()
